<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Forumo %(listname)s archyvai</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Forumo %(listname)s archyvai</h1>
     <p>
      <a href="%(listinfo)s">Paspaudę čia galite sužinoti daugiau apie forumą</a>;
      <a href="%(fullarch)s">Čia - atsisiųsti visą forumo archyvą</a>.
      (%(size)s).
     </p>
     %(noarchive_msg)s
     %(archive_listing_start)s
     %(archive_listing)s
     %(archive_listing_end)s
     </BODY>
     </HTML>
