Tämä sivu sisältää osan postituslistan <em>%(listname)s</em> 
viesteistä jotka ovat pidossa odottamassa hyväksyntääsi. Tällä hetkellä
näytetään %(description)s.

<p>Valitse jokaiselle ylläpitopyynölle toiminto ja napsauta <b>Lähetä
kaikki data</b> kun olet valmis. Lisätietoja <a href="%(detailsurl)s">here</a>.

<p>Voit myös <a href="%(summaryurl)s">Katsella yhteenvetoa</a> 
kaikista odottavista pyynnöistä.
