    </ul>
    <p>
      <a name="end"><b>Data del caberu mensax:</b></a> 
       <i>%(lastdate)s</i><br>
    <b>Archiv&aacute;u en:</b> <i>%(archivedate)s</i>
    <p>
   <ul>
         <li> <b>Mensaxes axeitaos por:</b>
	        %(thread_ref)s
		%(subject_ref)s
		%(author_ref)s
		%(date_ref)s
		<li><b><a href="%(listinfo)s">Mas infomaci&oacute;n sobro esta llista...
                    </a></b></li>
     </ul>
     <p>
     <hr>
     <i>Ficheru xener&aacute;u por 
     Pipermail %(version)s.</i>
  </body>
</html>
