<!-- updated to en 2.1 -->
Dieser Text kann sogenannte
<a href="http://docs.python.org/library/stdtypes.html#string-formatting-operations">
Python format strings</a> enthalten, die durch listenspezifische Werte 
ersetzt werden. 

M&ouml;gliche derartige "Attribute" sind:

<ul>
    <li><b>real_name</b> - Der "h&uuml;bsche" Name der Liste;
&uuml;blicherweise der Listenname in Gro&szlig;-/Kleinschreibung.

    <li><b>list_name</b> - Der Name der Liste f&uuml;r diverse URLs,
wo die Gro&szlig;-/Kleinschreibung wichtig ist.

    <li><b>host_name</b> - Der FQDN (fully qualified domain
name) des Listservers.

    <li><b>web_page_url</b> - Die Basis-URL f&uuml;r Mailman. Daran
wird zB <em>listinfo/%(list_name)s</em> angeh&auml;ngt, um die
URL der Infoseite der Liste zu erhalten.

    <li><b>description</b> - Eine kurze Beschreibung der
Mailingsliste.

    <li><b>info</b> - Die ausf&uuml;hrliche Beschreibung der
Mailingliste.

    <li><b>cgiext</b> - Die Dateinamenerweiterung f&uuml;r CGI
scripts.
</ul>
