Na tejto stránke nájdete všetky príspevky do konferencie <em>%(listname)s</em>,
ktoré neboli z nejakého dôvodu rozoslané a čakajú na Vaše rozhodnutie.
Momentálne sú zobrazené %(description)s

<p>U každej administratívnej požiadavky musíte vybrať činnosť, ktorá sa
s ňou má previesť a nakoniec vybrané činnosti uskutočníte kliknutím na 
<b>Potvrdiť všetky zmeny</b>. Podrobnejšie informácie o tom, ako
zaobchádzať s administratívnym rozhraním nájdete 
<a href="%(detailsurl)s">pod týmto odkazom</a>.

<p>Tiež si môžete prezrieť prehľad všetkých
<a href="%(summaryurl)s">čakajúcich požiadaviek</a> zobrazený tak, že
príspevky od jedného prispievateľa sú zlúčené dolopy a môžete
o nich rozhodnúť naraz.
