<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Archív konferencie %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Archív konferencie %(listname)s</h1>
     <p>
      Do tejto konferencie nebol zatial zaslaný žiaden príspevok.
      Preto je tento archív prázdny. Viac informácií o konferencii
      získate na <a href="%(listinfo)s">informačnej stránke.</a>.
     </p>
  </BODY>
  </HTML>
