<html>
<head>
    <title>Konferencia %(realname)s - prístup do súkromného archívu</title>
</head>
<body bgcolor="#ffffff">
<FORM METHOD=POST ACTION="%(action)s">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
		<B><FONT COLOR="#000000" SIZE="+1">Konferencia %(realname)s -
	    prístup do súkromného archívu</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">E-mailová adresa:</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">Heslo:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="Vstúpiť...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Dôležité:</em></strong> od tohto momentu potrebujete
      mať v prehliadači zapnuté cookies, inak sa budete musieť opätovne
      prihlásiť pri každej ďalšej činnosti.

      <p>Cookis pre sedenia sú použité pre prístup do súkromného archívu
      Mailman, aby ste sa nemuseli stále opätovne prihlasovať. Tento cookie
      vyprší, keď zavrete Váš prehliadač, alebo kliknete na stránke Vašich
      osobných nastavení na tlačidlo <em>Odhlásiť</em>.
</FORM>
</body>
</html>
