<html>
<head>
  <title>%(listname)s: prihlásenie ako %(who)s</title>
</head>
<body bgcolor="#ffffff">
<FORM METHOD=POST ACTION="%(path)s">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER"">
    <B><FONT COLOR="#000000" SIZE="+1">%(listname)s: prihlásenie ako
        %(who)s</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">Heslo pre %(who)s:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Vstúpiť...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Pozor:</em></strong> Aby systém fungoval 
      správne, musíte mať vo Vašom prehliadači povolené cookies.

      <p>Cookies sa používajú na to, aby ste nemuseli
      každú požiadavku znovu potvrdzovať heslom. Budú zmazané
      keď zavriete prehliadač alebo pri odhlásení.
      Odhlásiť sa môžete kliknutím na <em>Odhlásiť</em>. 
      Tento odkaz uvidíte až po úspešnom prihlásení.
</FORM>
</body>
</html>
